"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.WordWrapText = WordWrapText;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Separator = (token, i) => {
  return /*#__PURE__*/React.createElement(_reactNative.View, {
    key: `${token}${i}`,
    style: _containerStyle.separator
  });
};

const isTextAndRenderListTruthy = ([text, renderer]) => typeof text === 'string' && renderer instanceof Function;

const isTextNotEmpty = text => text.length > 0;

const parseLineBreak = ([text, renderer]) => {
  if (text.includes('\n')) {
    const regExp = new RegExp(/(\n)/);
    const tokens = text.split(regExp);
    const textAndRendererList = tokens.map(token => token === '\n' ? [token, Separator] : [token, renderer]);
    return textAndRendererList;
  }

  return [text, renderer];
};

const groupToTextAndRenderer = (acc, textOrRenderer) => {
  if (typeof textOrRenderer === 'string') {
    acc.push([textOrRenderer, () => /*#__PURE__*/React.createElement(_reactNative.View, null)]);
  } else {
    const lastIndex = acc.length - 1;
    acc[lastIndex][1] = textOrRenderer;
  }

  return acc;
};

const parseWhiteSpace = ([text, renderer]) => {
  const regExp = new RegExp(/(?<=\s)/);
  const tokens = text.split(regExp);
  return [tokens, renderer];
};

function WordWrapText(props) {
  const {
    textAndRendererList,
    containerStyle = {}
  } = props;

  if (!Array.isArray(textAndRendererList)) {
    return null;
  }

  const textComponents = textAndRendererList.filter(isTextAndRenderListTruthy).map(parseLineBreak).flat(2).reduce(groupToTextAndRenderer, []).map(parseWhiteSpace).map(([tokens, renderer]) => tokens.filter(isTextNotEmpty).map(renderer));

  const composedContainerStyle = _reactNative.StyleSheet.flatten([_containerStyle.container, containerStyle]);

  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: composedContainerStyle
  }, textComponents);
}

const _containerStyle = _reactNative.StyleSheet.create({
  container: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  separator: {
    flexBasis: '100%'
  }
});
//# sourceMappingURL=WordWrapText.js.map