import * as React from 'react';
import { StyleSheet, View } from 'react-native';

const Separator = (token, i) => {
  return /*#__PURE__*/React.createElement(View, {
    key: `${token}${i}`,
    style: _containerStyle.separator
  });
};

const isTextAndRenderListTruthy = ([text, renderer]) => typeof text === 'string' && renderer instanceof Function;

const isTextNotEmpty = text => text.length > 0;

const parseLineBreak = ([text, renderer]) => {
  if (text.includes('\n')) {
    const regExp = new RegExp(/(\n)/);
    const tokens = text.split(regExp);
    const textAndRendererList = tokens.map(token => token === '\n' ? [token, Separator] : [token, renderer]);
    return textAndRendererList;
  }

  return [text, renderer];
};

const groupToTextAndRenderer = (acc, textOrRenderer) => {
  if (typeof textOrRenderer === 'string') {
    acc.push([textOrRenderer, () => /*#__PURE__*/React.createElement(View, null)]);
  } else {
    const lastIndex = acc.length - 1;
    acc[lastIndex][1] = textOrRenderer;
  }

  return acc;
};

const parseWhiteSpace = ([text, renderer]) => {
  const regExp = new RegExp(/(?<=\s)/);
  const tokens = text.split(regExp);
  return [tokens, renderer];
};

export function WordWrapText(props) {
  const {
    textAndRendererList,
    containerStyle = {}
  } = props;

  if (!Array.isArray(textAndRendererList)) {
    return null;
  }

  const textComponents = textAndRendererList.filter(isTextAndRenderListTruthy).map(parseLineBreak).flat(2).reduce(groupToTextAndRenderer, []).map(parseWhiteSpace).map(([tokens, renderer]) => tokens.filter(isTextNotEmpty).map(renderer));
  const composedContainerStyle = StyleSheet.flatten([_containerStyle.container, containerStyle]);
  return /*#__PURE__*/React.createElement(View, {
    style: composedContainerStyle
  }, textComponents);
}

const _containerStyle = StyleSheet.create({
  container: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  separator: {
    flexBasis: '100%'
  }
});
//# sourceMappingURL=WordWrapText.js.map